@@ -116,7 +116,7 @@ class QLDBClient:
         Name: str,
         InclusiveStartTime: datetime,
         ExclusiveEndTime: datetime,
-        S3ExportConfiguration: S3ExportConfigurationTypeDef,
+        S3ExportConfiguration: "S3ExportConfigurationTypeDef",
         RoleArn: str,
     ) -> ExportJournalToS3ResponseTypeDef:
         """
@@ -137,8 +137,8 @@ class QLDBClient:
     def get_block(
         self,
         Name: str,
-        BlockAddress: ValueHolderTypeDef,
-        DigestTipAddress: ValueHolderTypeDef = None,
+        BlockAddress: "ValueHolderTypeDef",
+        DigestTipAddress: "ValueHolderTypeDef" = None,
     ) -> GetBlockResponseTypeDef:
         """
         [Client.get_block documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/qldb.html#QLDB.Client.get_block)
@@ -152,9 +152,9 @@ class QLDBClient:
     def get_revision(
         self,
         Name: str,
-        BlockAddress: ValueHolderTypeDef,
+        BlockAddress: "ValueHolderTypeDef",
         DocumentId: str,
-        DigestTipAddress: ValueHolderTypeDef = None,
+        DigestTipAddress: "ValueHolderTypeDef" = None,
     ) -> GetRevisionResponseTypeDef:
         """
         [Client.get_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/qldb.html#QLDB.Client.get_revision)
@@ -198,7 +198,7 @@ class QLDBClient:
         LedgerName: str,
         RoleArn: str,
         InclusiveStartTime: datetime,
-        KinesisConfiguration: KinesisConfigurationTypeDef,
+        KinesisConfiguration: "KinesisConfigurationTypeDef",
         StreamName: str,
         Tags: Dict[str, str] = None,
         ExclusiveEndTime: datetime = None,
